@@ -1,3 +1,9 @@
+# @package      hubzero-simtool
+# @file         utils.py
+# @copyright    Copyright (c) 2019-2021 The Regents of the University of California.
+# @license      http://opensource.org/licenses/MIT MIT
+# @trademark    HUBzero is a registered trademark of The Regents of the University of California.
+#
 import os
 import sys
 import re
@@ -9,6 +15,16 @@ import jsonpickle
 from .params import Params
 
 def parse(inputs):
+   """Convert YAML expression of SimTool input or outputs into a collection
+      of Params objects
+
+      Args:
+          inputs: YAML expression of SimTool inputs or outputs
+
+      Returns:
+          d: dictionary of Params objects.  Each Params objects represents
+              one SimTool input or output.
+   """
    d = Params()
    for i in inputs:
       t = inputs[i]['type']
@@ -20,6 +36,24 @@ def parse(inputs):
 
 
 def getValidatedInputs(inputs):
+   """Test inputs for validity.
+
+      Any invalid inputs are reported.  This function is intended for use
+      in the 'parameters' cell.  The following code will set parameters to
+      default values and cause an error if default values are in error.
+
+      Note:
+          from simtool import getValidatedInputs
+
+          defaultInputs = getValidatedInputs(INPUTS)
+          if defaultInputs: globals().update(defaultInputs)
+
+      Args:
+          inputs: YAML representation of SimTool inputs.
+
+      Returns:
+          dictionary of Params.
+   """
    validatedInputs = {}
    try:
       params = parse(inputs)
@@ -33,7 +67,7 @@ def getValidatedInputs(inputs):
 
 
 def _get_extra_files(nbPath):
-   """ Internal function to search the notebook for a cell tagged
+   """Internal function to search the notebook for a cell tagged
    'FILES' with content 'EXTRA_FILES=xxx' where 'xxx' is a list of files
    or '*'
    """
@@ -65,7 +99,7 @@ def _get_extra_files(nbPath):
 
 
 def _getSimToolDescription(nbPath):
-   """ Internal function to search the notebook for a cell tagged
+   """Internal function to search the notebook for a cell tagged
    'DESCRIPTION' with content 'DESCRIPTION=xxx' where 'xxx' is a
    string describing the simtool
    """
@@ -92,6 +126,12 @@ def _getSimToolDescription(nbPath):
 
 
 def getGetSimToolNameRevisionFromEnvironment():
+   """Determine the SimTool name and revision from environment set by submit
+
+      Returns:
+          simToolName: SimTool name set by submit
+          simToolRevision: SimTool revision set by submit
+   """
    simToolName     = None
    simToolRevision = None
    try:
@@ -149,12 +189,7 @@ def _getSimToolNotebookMetaData(nbPath):
 def findSimToolNotebook(simToolName,simToolRevision=None):
    """Lookup simtool by name and revision.
 
-   Returns:
-       A dictionary containing -
-           notebookPath    - the full path name of the simtool notebook,
-           simToolName     - the simtool shortname
-           simToolRevision - the simtool revision (if installed or published)
-           published       - boolean which is True if the notebook is published
+      This function has been replaced by searchForSimTool(simToolName,simToolRevision=None)
    """
    simToolLocation = {}
    simToolLocation['notebookPath']    = None
@@ -254,10 +289,10 @@ def findSimToolNotebook(simToolName,simToolRevision=None):
 
 def findInstalledSimToolNotebooks(querySimToolName=None,
                                   returnString=True):
-   """Find all the revisions of simToolName.
+   """Find all the revisions of a SimTool.
 
-   Returns:
-      Ordered lists of installed and published revisions
+       Returns:
+           Ordered lists of installed and published revisions
    """
    installedSimToolRevisions = {}
 
@@ -320,6 +355,19 @@ def findInstalledSimToolNotebooks(querySimToolName=None,
 
 
 def searchForSimTool(simToolName,simToolRevision=None):
+   """Lookup simtool by name and revision.
+
+      Args:
+          simToolName: SimTool name.
+          simToolRevision: SimTool revision, typically rNN.
+
+      Returns:
+          A simToolLocation dictionary containing
+              notebookPath    - the full path name of the simtool notebook,
+              simToolName     - the simtool shortname
+              simToolRevision - the simtool revision (if installed or published)
+              published       - boolean which is True if the notebook is published
+   """
    foundIt = True
    if simToolRevision is None:
       notebookPath = os.path.join('simtool',"%s.ipynb" % (simToolName))
@@ -418,10 +466,10 @@ def searchForSimTool(simToolName,simToolRevision=None):
 def _find_simTool(simToolName,simToolRevision=None):
     """Lookup simtool by name and revision.
 
-    Returns:
-        A tuple containing the full path name of the simtool notebook,
-        the tool name, the tool revision (if published) and a boolean which is True if the notebook
-        is published
+        Returns:
+            A tuple containing the full path name of the simtool notebook,
+            the tool name, the tool revision (if published) and a boolean which is True if the notebook
+            is published
     """
     if   simToolRevision and not simToolName.endswith('.ipynb'):
         simToolNotebook = simToolName + '.ipynb'
@@ -481,6 +529,14 @@ def getNotebookInputs(nb):
 
 
 def getSimToolInputs(simToolLocation):
+   """Get required SimTool inputs definition.
+
+      Args:
+          simToolLocation:  A dictionary containing information on SimTool notebook
+              location and status.
+      Returns:
+          A simtool.Params object defining expected inputs.
+   """
    nbPath = simToolLocation['notebookPath']
    nb = load_notebook_node(nbPath)
 
@@ -564,6 +620,14 @@ def getNotebookOutputs(nb):
 
 
 def getSimToolOutputs(simToolLocation):
+   """Get SimTool outputs definition.
+
+      Args:
+          simToolLocation:  A dictionary containing information on SimTool notebook
+              location and status.
+      Returns:
+          A simtool.Params object defining expected outputs.
+   """
    nbPath = simToolLocation['notebookPath']
    nb = load_notebook_node(nbPath)
 
